@@ -38,7 +38,7 @@ def dt(start: datetime.datetime, end: Optional[datetime.datetime] = None) -> dat
         The elapsed time.
 
     """
-    end = end if isinstance(end, datetime.datetime) else now()
+    end = end if (end is not None) else now()
     return end - start
 
 
